=== modified file 'drizzled/set_var.cc'
--- drizzled/set_var.cc	2010-12-18 04:43:40 +0000
+++ drizzled/set_var.cc	2010-12-30 19:33:46 +0000
@@ -52,22 +52,26 @@
     -1  ERROR, message not sent
 */
 
-int sql_set_variables(Session *session, List<set_var_base> *var_list)
+int sql_set_variables(Session *session, const SetVarVector &var_list)
 {
   int error;
-  List_iterator_fast<set_var_base> it(*var_list);
-
-  set_var_base *var;
-  while ((var=it++))
+
+  SetVarVector::const_iterator it(var_list.begin());
+
+  while (it != var_list.end())
   {
-    if ((error= var->check(session)))
+    if ((error= (*it)->check(session)))
       goto err;
+    ++it;
   }
   if (!(error= test(session->is_error())))
   {
-    it.rewind();
-    while ((var= it++))
-      error|= var->update(session);         // Returns 0, -1 or 1
+    it= var_list.begin();
+    while (it != var_list.end())
+    {
+      error|= (*it)->update(session);         // Returns 0, -1 or 1
+      ++it;
+    }
   }
 
 err:

=== modified file 'drizzled/set_var.h'
--- drizzled/set_var.h	2010-12-18 04:43:40 +0000
+++ drizzled/set_var.h	2010-12-30 19:33:46 +0000
@@ -20,6 +20,8 @@
 #ifndef DRIZZLED_SET_VAR_H
 #define DRIZZLED_SET_VAR_H
 
+#include <boost/shared_ptr.hpp>
+
 #include "drizzled/memory/sql_alloc.h"
 #include "drizzled/sql_list.h"
 #include "drizzled/lex_string.h"
@@ -51,8 +53,7 @@
   Classes for parsing of the SET command
 ****************************************************************************/
 
-class set_var_base :
-  public memory::SqlAlloc
+class set_var_base
 {
 public:
   set_var_base() {}
@@ -101,7 +102,9 @@
   int update(Session *session);
 };
 
-int sql_set_variables(Session *session, List<set_var_base> *var_list);
+typedef boost::shared_ptr<set_var_base> SetVarPtr;
+typedef std::vector<SetVarPtr> SetVarVector;
+int sql_set_variables(Session *session, const SetVarVector &var_list);
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/sql_lex.h'
--- drizzled/sql_lex.h	2010-12-24 07:15:43 +0000
+++ drizzled/sql_lex.h	2010-12-30 19:33:46 +0000
@@ -850,7 +850,7 @@
   List<Lex_Column>    columns;
   List<Item>	      *insert_list,field_list,value_list,update_list;
   List<List_item>     many_values;
-  List<set_var_base>  var_list;
+  SetVarVector  var_list;
   /*
     A stack of name resolution contexts for the query. This stack is used
     at parse time to set local name resolution contexts for various parts

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-12-30 18:34:46 +0000
+++ drizzled/sql_yacc.yy	2010-12-30 19:33:46 +0000
@@ -6449,30 +6449,33 @@
             { /* System variable */
               if ($1)
                 lex->option_type= $1;
-              lex->var_list.push_back(new set_var(lex->option_type, $2.var,
-                                      &$2.base_name, $4));
+              lex->var_list.push_back(SetVarPtr(new set_var(lex->option_type, $2.var,
+                                      &$2.base_name, $4)));
             }
           }
         | option_type TRANSACTION_SYM ISOLATION LEVEL_SYM isolation_types
           {
             LEX *lex=Lex;
             lex->option_type= $1;
-            lex->var_list.push_back(new set_var(lex->option_type,
+            lex->var_list.push_back(SetVarPtr(new set_var(lex->option_type,
                                                 find_sys_var("tx_isolation"),
                                                 &null_lex_str,
-                                                new Item_int((int32_t) $5)));
+                                                new Item_int((int32_t)
+                                                $5))));
           }
         ;
 
 option_value:
           '@' ident_or_text equal expr
           {
-            Lex->var_list.push_back(new set_var_user(new Item_func_set_user_var($2,$4)));
+            Lex->var_list.push_back(SetVarPtr(new set_var_user(new
+                    Item_func_set_user_var($2,$4))));
           }
         | '@' '@' opt_var_ident_type internal_variable_name equal set_expr_or_default
           {
             LEX *lex=Lex;
-            lex->var_list.push_back(new set_var($3, $4.var, &$4.base_name, $6));
+            lex->var_list.push_back(SetVarPtr(new set_var($3, $4.var,
+                    &$4.base_name, $6)));
           }
         ;
 

=== modified file 'drizzled/statement/set_option.cc'
--- drizzled/statement/set_option.cc	2010-12-18 04:43:40 +0000
+++ drizzled/statement/set_option.cc	2010-12-30 19:33:46 +0000
@@ -29,13 +29,12 @@
 bool statement::SetOption::execute()
 {
   TableList *all_tables= session->lex->query_tables;
-  List<set_var_base> *lex_var_list= &session->lex->var_list;
 
   if (session->openTablesLock(all_tables))
   {
     return true;
   }
-  bool res= sql_set_variables(session, lex_var_list);
+  bool res= sql_set_variables(session, session->lex->var_list);
   if (res)
   {
     /*

